import { FirebaseAlertData } from '.';
import { CloudEvent, CloudFunction } from '../../core';
import * as options from '../../options';
/**
 * The internal payload object for billing plan updates.
 * Payload is wrapped inside a FirebaseAlertData object.
 */
export interface PlanUpdatePayload {
    ['@type']: 'com.google.firebase.firebasealerts.PlanUpdatePayload';
    billingPlan: string;
    principalEmail: string;
}
/**
 * The internal payload object for billing plan automated updates.
 * Payload is wrapped inside a FirebaseAlertData object.
 */
export interface PlanAutomatedUpdatePayload {
    ['@type']: 'com.google.firebase.firebasealerts.PlanAutomatedUpdatePayload';
    billingPlan: string;
}
interface WithAlertType {
    alertType: string;
}
/**
 * A custom CloudEvent for billing Firebase Alerts (with custom extension attributes).
 */
export declare type BillingEvent<T> = CloudEvent<FirebaseAlertData<T>, WithAlertType>;
/**
 * Declares a function that can handle a billing plan update event.
 */
export declare function onPlanUpdatePublished(handler: (event: BillingEvent<PlanUpdatePayload>) => any | Promise<any>): CloudFunction<FirebaseAlertData<PlanUpdatePayload>>;
export declare function onPlanUpdatePublished(opts: options.EventHandlerOptions, handler: (event: BillingEvent<PlanUpdatePayload>) => any | Promise<any>): CloudFunction<FirebaseAlertData<PlanUpdatePayload>>;
/**
 * Declares a function that can handle an automated billing plan update event.
 */
export declare function onPlanAutomatedUpdatePublished(handler: (event: BillingEvent<PlanAutomatedUpdatePayload>) => any | Promise<any>): CloudFunction<FirebaseAlertData<PlanAutomatedUpdatePayload>>;
export declare function onPlanAutomatedUpdatePublished(opts: options.EventHandlerOptions, handler: (event: BillingEvent<PlanAutomatedUpdatePayload>) => any | Promise<any>): CloudFunction<FirebaseAlertData<PlanAutomatedUpdatePayload>>;
export {};
